@@ -75,7 +75,10 @@ class InstallerGUI(Frame):
 					self.installer.install()
 					self.installed = True
 
-					self.installer.unzip()
+					if checkname.return_format(self.filename) == "zip":
+						self.installer.unzip()
+					else:
+						pass
 				else:
 					pass
 			else:
@@ -90,11 +93,13 @@ class Installer(object):
 		self.master = master
 
 		self.sizeThread = Thread(target=self.getSize)
+
+		self.filename = filename
 		
 
 	def install(self):
 		u = urllib2.urlopen(self.url)
-		f = open(filename, 'wb')
+		f = open(self.filename, 'wb')
 		file_size = int(u.getheader('Content-Length'))
 		file_size_dl = 0
 		block_sz = 8192
@@ -113,8 +118,8 @@ class Installer(object):
 
 	def unzip(self):
 		try:
-			with zipfile.ZipFile(filename, 'r') as zip_ref:
-			    zip_ref.extractall(checkname.return_filename_without_format(filename))
+			with zipfile.ZipFile(self.filename, 'r') as zip_ref:
+			    zip_ref.extractall(checkname.return_filename_without_format(self.filename))
 			    zip_ref.close()
 
 			    self.master.waitingText['text'] = "Extracting..."
@@ -130,13 +135,13 @@ class Installer(object):
 			self.unzip()
 
 	def rmvFiles(self):
-		os.remove(filename)
+		os.remove(self.filename)
 
 		for i in range(26):
 			self.master.progressBar['value'] = 75 + i
 			time.sleep(0.01)
 
-		self.master.waitingText['text'] = "Installed " + filename + " with 0 errors"
+		self.master.waitingText['text'] = "Installed " + self.filename + " with 0 errors"
 
 		self.master.installBtn['state'] = NORMAL
 		self.master.installBtn['text'] = "Quit"
